# API Reference

This directory contains the API reference for Harlem.
Modules meant for more advanced users are in the `advanced` directory.

## Disclaimer

Currently, classes and functions are selected manually,
and generation is also done manually using pydoc-markdown.

If you see anything that is missing or not up to date, please open an issue or a pull request.

